@@ -22,6 +22,16 @@ sub error {
     shift->session->error(@_)
 }
 
+sub setenv {
+    my ($self, %env) = @_;
+    my $rc = 1;
+    while (my ($k, $v) = each %env) {
+        $self->_setenv($k, $v)
+            or undef $rc;
+    }
+    $rc
+}
+
 
 # tie interface
 
@@ -102,7 +112,10 @@ method can be used to check for read/write availability and other conditions.
 
 Sets remote environment variables.  Note that most implementations do not allow
 environment variables to be freely set.  Pass in a list of keys and values
-with the values to set.  Returns the number of successful sets.
+with the values to set.
+
+It returns a true value when all the given environment variables are
+correctly set.
 
 =head2 blocking ( flag )
 
@@ -193,6 +206,13 @@ Attempts to write the buffer to the channel.  Returns number of bytes written,
 undef on failure.  If ext is present and set, writes to the extended data
 channel (stderr).
 
+In versions of this module prior to 0.57, when working in
+non-blocking mode, the would-block condition was signaled by returning
+LIBSSH2_ERROR_EAGAIN (a negative number) while leaving the session
+error status unset. From version 0.56, C<undef> is returned and the
+session error status is set to LIBSSH2_ERROR_EAGAIN in a similar
+fashion to the other errors.
+
 =head2 flush ( [ ext ] )
 
 Flushes the channel; if ext is present and set, flushes extended data channel.
@@ -203,6 +223,31 @@ Returns number of bytes flushed, undef on error.
 Returns the exit signal of the command executed on the channel. Requires libssh
 1.2.8 or higher.
 
+=head2 window_read
+
+Returns the number of bytes which the remote end may send without
+overflowing the window limit.
+
+In list context it also returns the number of bytes that are
+immediately available for read and the size of the initial window.
+
+=head2 window_write
+
+Returns the number of bytes which may be safely written on the channel
+without blocking. In list context it also returns the size of the
+initial window.
+
+=head2 receive_window_adjust (adjustment [, force])
+
+Adjust the channel receive window by the given C<adjustment> bytes.
+
+If the amount to be adjusted is less than C<LIBSSH2_CHANNEL_MINADJUST>
+and force is false the adjustment amount will be queued for a later
+packet.
+
+On success returns the new size of the receive window. On failure it
+returns undef.
+
 =head1 SEE ALSO
 
 L<Net::SSH2>.
